@@ -2,7 +2,6 @@ package Clustericious::Plugin::PlugAuth;
 
 use Clustericious::Log;
 use Mojo::ByteStream qw/b/;
-use Mojo::UserAgent;
 use Mojo::URL;
 
 use Clustericious::Config;
@@ -11,7 +10,7 @@ use Mojo::Base 'Mojolicious::Plugin';
 use warnings;
 use strict;
 
-our $VERSION = '0.9924_02';
+our $VERSION = '0.9924_03';
 
 =head1 NAME
 
@@ -118,11 +117,11 @@ sub authenticate {
     my $userinfo = b($str)->b64_decode;
     my ($user,$pw) = split /:/, $userinfo;
 
-    my $self_plug_auth = ref($c->app) =~ /^(?:Simple|Plug)Auth$/;
+    my $self_plug_auth = 0;
 
     # VIP treatment for some hosts
     my $ip = $c->tx->remote_address;
-    my $tx = $self_plug_auth ? $c->subdispatch(GET => "$config_url/host/$ip/trusted") : $ua->get("$config_url/host/$ip/trusted");
+    my $tx = $ua->get("$config_url/host/$ip/trusted");
     if ( my $res = $tx->success ) {
         if ( $res->code == 200 ) {
             TRACE "Host $ip is trusted, not authenticating";
@@ -147,20 +146,18 @@ sub authenticate {
 
     my $check;
     my $res;
-    if($self_plug_auth) {
-        $check = $c->data->check_credentials($user, $pw) ? 200 : 401;
+
+    if ($ENV{HARNESS_ACTIVE}) {
+        my $saved = $ua->inactivity_timeout;
+        $ua->inactivity_timeout(1);
+        $tx = $ua->head($auth_url);
+        $ua->inactivity_timeout($saved);
     } else {
-        if ($ENV{HARNESS_ACTIVE}) {
-            my $saved = $ua->inactivity_timeout;
-            $ua->inactivity_timeout(1);
-            $tx = $ua->head($auth_url);
-            $ua->inactivity_timeout($saved);
-        } else {
-            $tx = $ua->head($auth_url);
-        }
-        $res = $tx->res;
-        $check = $res->code();
+        $tx = $ua->head($auth_url);
     }
+    $res = $tx->res;
+    $check = $res->code();
+
     if(!defined $check || $check == 503) {
         $c->res->headers->www_authenticate(qq[Basic realm="$realm"]);
         WARN ("Error connecting to PlugAuth at $config_url");
@@ -196,7 +193,7 @@ sub authorize {
     $resource =~ s[^/][];
     my $url = Mojo::URL->new( join '/', $self->config_url,
         "authz/user", $user, $action, $resource );
-    my $code = (ref($c->app) =~ /^(?:Simple|Plug)Auth$/ ? $c->subdispatch(HEAD => $url) : Mojo::UserAgent->new->head($url))->res->code;
+    my $code = $c->ua->head($url)->res->code;
     return 1 if $code && $code == 200;
     INFO "Unauthorized access by $user to $action $resource";
     if($code == 503) {
